Rack Group - Nautobot Documentation

Skip to content

# Rack Groups

Racks can be organized into groups, which can be nested into themselves similar to locations. As with locations, how you choose to designate rack groups will depend on the nature of your organization.

Each rack group must be assigned to a parent location. Rack groups may optionally be nested within one another to model a multi-level hierarchy.

The name and facility ID of each rack within a group must be unique. (Racks not assigned to the same rack group may have identical names and/or facility IDs.)